@@ -813,7 +813,7 @@ static void sspm_make_part(struct mime_impl *impl,
             }
 
             /* add a end-of-string after the data, just in case binary
-               data from decode64 gets passed to a tring handling
+               data from decode64 gets passed to a string handling
                routine in add_line  */
             data[*size + 1] = '\0';
 
@@ -868,7 +868,7 @@ static void *sspm_make_multipart_subpart(struct mime_impl *impl, struct sspm_hea
         /* Error. Multipart headers must have a boundary */
 
         sspm_set_error(parent_header, SSPM_NO_BOUNDARY_ERROR, 0);
-        /* read all of the reamining lines */
+        /* read all of the remaining lines */
         while (sspm_get_next_line(impl) != 0) {
         }
 
@@ -1206,7 +1206,7 @@ static void sspm_append_hex(struct sspm_buffer *buf, char ch)
 {
     char tmp[4];
 
-    snprintf(tmp, sizeof(tmp), "=%02X", (unsigned int)ch);
+    snprintf(tmp, sizeof(tmp), "=%02X", (unsigned char)ch);
 
     sspm_append_string(buf, tmp);
 }
