@@ -135,6 +135,7 @@ static void convert_floating_time_to_utc(struct icaltimetype *itt)
     t = mktime(&tmp_tm);
 
     /* Now convert back to a struct tm, but with a UTC time. */
+    memset(&utc_tm, 0, sizeof(struct tm));
     if (!gmtime_r(&t, &utc_tm)) {
         *itt = itt->is_date ? icaltime_null_date () : icaltime_null_time ();
         return;
@@ -1258,7 +1259,7 @@ static void *rule_prop(int icaltype, VObject *object, icalcomponent *comp,
     return (void *)prop;
 }
 
-/* directly convertable property. The string representation of vcal is
+/* directly convertible property. The string representation of vcal is
    the same as ical */
 
 void *dc_prop(int icaltype, VObject *object, icalcomponent *comp, icalvcal_defaults *defaults)
@@ -1481,7 +1482,7 @@ static void icalvcal_traverse_objects(VObject *object,
                                       icalproperty *last_prop, icalvcal_defaults *defaults)
 {
     VObjectIterator iterator;
-    const char *name = "[No Name]";
+    const char *name;
     icalcomponent *subc = 0;
     int i;
 
