@@ -3,19 +3,19 @@
 # FILE: Time.py
 # CREATOR: eric
 #
-# (C) COPYRIGHT 2001, Eric Busboom <eric@softwarestudio.org>
+# (C) COPYRIGHT 2001, Eric Busboom <eric@civicknowledge.com>
 # (C) COPYRIGHT 2001, Patrick Lewis <plewis@inetarena.com>
 #
 # This library is free software; you can redistribute it and/or modify
 # it under the terms of either:
 #
 #   The LGPL as published by the Free Software Foundation, version
-#   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.txt
+#   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.txt
 #
 # Or:
 #
 #   The Mozilla Public License Version 2.0. You may obtain a copy of
-#   the License at http://www.mozilla.org/MPL/
+#   the License at https://www.mozilla.org/MPL/
 #======================================================================
 
 from LibicalWrap import *
@@ -78,11 +78,11 @@ class Time(Property):
         self.value(icaltime_as_ical_string(self.tt),"DATE-TIME")
 
     def valid(self):
-        " Return true if this is a valid time "
+        " Returns true if this is a valid time "
         return not icaltime_is_null_time(self.tt)
 
     def utc_seconds(self,v=None):
-        """ Return or set time in seconds past POSIX epoch"""
+        """ Returns or sets time in seconds past POSIX epoch"""
         tz = icaltimezone_get_builtin_timezone(self.timezone())
         if (v!=None):
             self.tt = icaltime_from_timet_with_zone(v,0,tz)
@@ -91,15 +91,15 @@ class Time(Property):
         return icaltime_as_timet_with_zone(self.tt, tz)
 
     def is_utc(self):
-        """ Return a boolean indicating if time is in UTC """
+        """ Returns a boolean indicating if time is in UTC """
         return icaltime_is_utc(self.tt)
 
     def is_date(self):
-        """ Return a boolean indicating if time is actually a date """
+        """ Returns a boolean indicating if time is actually a date """
         return icaltime_is_date(self.tt)
 
     def timezone(self,v=None):
-        """ Return, set (if none) or alter the timezone for this time """
+        """ Returns, set (if none) or alter the timezone for this time """
 
         origtz = icaltime_get_tzid(self.tt)
 
@@ -216,4 +216,4 @@ class Time(Property):
             seconds = self.utc_seconds() - other.seconds()
             return Time(seconds)
         else:
-            raise TypeError, "subtraction with Time reqires Time or Duration"
+            raise TypeError, "subtraction with Time requires Time or Duration"
