@@ -29,7 +29,7 @@
 /*int sspm_parse_mime(struct sspm_part *parts,
                size_t max_parts,
                struct sspm_action_map *actions,
-               char* (*get_string)(char *s, size_t size, void* data),
+               char* (*get_string)(char *s, size_t size, void *data),
                void *get_string_data,
                struct sspm_header *first_header
     );
@@ -96,10 +96,15 @@ int main(int argc, char *argv[])
     program_name = (char *)strrchr((char *)argv[0], '/');
     program_name++;
 
+    opt.input_file = NULL;
+
     while ((c = getopt(argc, argv, "nsbqi:S:c:")) != -1) {
         switch (c) {
         case 'i':{
                 /* Input comes from named file */
+                if (opt.input_file) {
+                    free(opt.input_file);
+                }
                 opt.input_file = strdup(optarg);
                 break;
             }
@@ -206,6 +211,7 @@ int main(int argc, char *argv[])
         } d;
 
         size = 0;
+        memset(array, 0, sizeof(array));
         for (i = 0; i < 1024 && !feof(f); ++i) {
             if (fgets(temp, 1024, f) != NULL) {
                 array[i] = strdup(temp);
@@ -293,7 +299,7 @@ int main(int argc, char *argv[])
     }
 
     if (opt.sleepy != 0) {
-        sleep((unsigned int)opt.sleepy);
+        (void)sleep((unsigned int)opt.sleepy);
     }
 
     if (opt.input_file != 0) {
